projectal.entities.calendar API documentation

# projectal.entities.calendar

View Source

    from projectal.errors import UnsupportedException

    from projectal.entity import Entity

    class Calendar(Entity):
        """
        Implementation of the [Calendar](https://projectal.com/docs/latest/#tag/Calendar) API.
        """
        _path = 'calendar'
        _name = 'CALENDAR'

        @classmethod
        def create(cls, holder, entity):
            """Create a Calendar

            `holder`: `uuId` of the owner

            `entity`: The fields of the entity to be created
            """
            params = "?holder=" + holder
            return super().create(entity, params)

        @classmethod
        def list(cls, expand=False, links=None):
            raise UnsupportedException("Calendar list is not supported by the API.")

class Calendar(projectal.entity.Entity):
View Source

    class Calendar(Entity):
        """
        Implementation of the [Calendar](https://projectal.com/docs/latest/#tag/Calendar) API.
        """
        _path = 'calendar'
        _name = 'CALENDAR'

        @classmethod
        def create(cls, holder, entity):
            """Create a Calendar

            `holder`: `uuId` of the owner

            `entity`: The fields of the entity to be created
            """
            params = "?holder=" + holder
            return super().create(entity, params)

        @classmethod
        def list(cls, expand=False, links=None):
            raise UnsupportedException("Calendar list is not supported by the API.")

Implementation of the Calendar API.

@classmethod
def create(cls, holder, entity):
View Source

        @classmethod
        def create(cls, holder, entity):
            """Create a Calendar

            `holder`: `uuId` of the owner

            `entity`: The fields of the entity to be created
            """
            params = "?holder=" + holder
            return super().create(entity, params)

Create a Calendar

`holder`: `uuId` of the owner

`entity`: The fields of the entity to be created

@classmethod
def list(cls, expand=False, links=None):
View Source

        @classmethod
        def list(cls, expand=False, links=None):
            raise UnsupportedException("Calendar list is not supported by the API.")

Return a list of all entity UUIDs of this type.

You may pass in `expand=True` to get full Entity objects instead, but be aware this may be very slow if you have thousands of objects.

If you are expanding the objects, you may further expand the results with `links`.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  save
  clone
  history
  match
  match_startswith
  match_endswith
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy